/* Data definition tables */

CREATE TABLE LOOMSPEC (
  REF CHAR(12) NOT NULL,
  POSN INTEGER NOT NULL,
  TYPE CHAR(25) NOT NULL,
  DESCR CHAR(25) NOT NULL,
  CONSTRAINT PLOOMSPEC PRIMARY KEY (REF)
)

CREATE TABLE WARPTYPE (
  WARPTYPE CHAR(1) NOT NULL,
  TOTALENDS INTEGER,
  DENTSPERCM DOUBLE PRECISION,
  AVEHRS DOUBLE PRECISION,
  GREIGELENPERCENT DOUBLE PRECISION,
  WARPLEN INTEGER,
  WARPWGT DOUBLE PRECISION,
  CONSTRAINT PWARPTYPE PRIMARY KEY (WARPTYPE)
)

CREATE TABLE FABRICTYPE (
  FABRICSTRU CHAR(2) NOT NULL,
  FABRICCOL CHAR(3) NOT NULL,
  WARPTYPE CHAR(2) NOT NULL,
  WARPCOL CHAR(3) NOT NULL,
  WEFTSTRU CHAR(4) NOT NULL,
  WEFTTWIST CHAR(2) NOT NULL,
  WEFTCOL CHAR(3) NOT NULL,
  PIECELEN INTEGER NOT NULL,
  WARPPCEWGT DOUBLE PRECISION,
  WEFTPCEWGT DOUBLE PRECISION,
  HRSPERPIECE DOUBLE PRECISION,
  CONSTRAINT PFABRICTYPE PRIMARY KEY (FABRICSTRU, FABRICCOL),
  CONSTRAINT FFABRICSTRUWARPTYPE FOREIGN KEY (WARPTYPE) 
    REFERENCES WARPTYPE
)

CREATE TABLE STRULOOM (
  FABRICSTRU CHAR(2) NOT NULL,
  LOOMTYPE CHAR(25) NOT NULL,
  CONSTRAINT PSTRULOOM PRIMARY KEY (FABRICSTRU, LOOMTYPE)
)

CREATE TABLE DOWNTIMETYPE (
  DESCR CHAR(20) NOT NULL,
  CONSTRAINT PDOWNTIME PRIMARY KEY (DESCR)
)

/* Scenario storage tables */

CREATE TABLE SCENARIO (
  SCENARIONO INTEGER NOT NULL,
  DESCR CHAR(25),
  CONSTRAINT PSCENARIO PRIMARY KEY (SCENARIONO)
)

CREATE TABLE WEAVEJOB (
  SCENARIONO INTEGER NOT NULL,
  LOOMNO INTEGER NOT NULL,
  JOBNO INTEGER NOT NULL,
  PLACENO INTEGER NOT NULL,
  WARPTYPE CHAR(2) NOT NULL,
  WARPCOL CHAR(3) NOT NULL,
  WARPLEN INTEGER NOT NULL,
  STARTDATE DATE,
  ENDDATE DATE,
  CONSTRAINT PWEAVEJOB PRIMARY KEY (SCENARIONO, JOBNO),
  CONSTRAINT WEAVEJOBSCENARIONO FOREIGN KEY (SCENARIONO)
    REFERENCES SCENARIO
)

CREATE TABLE WEAVEITEM (
  SCENARIONO INTEGER NOT NULL,
  SCHEDULENO INTEGER NOT NULL,
  JOBNO INTEGER NOT NULL,
  ITEMNO INTEGER NOT NULL,
  PLACENO INTEGER NOT NULL,
  FABRICSTRU CHAR(2) NOT NULL,
  FABRICCOL CHAR(3) NOT NULL,
  WEFTCOL CHAR(3) NOT NULL,
  WEFTPCS INTEGER NOT NULL,
  CONSTRAINT PSCENARIOJOBITEM PRIMARY KEY (SCENARIONO, JOBNO, ITEMNO),
  CONSTRAINT FWEAVEITEM FOREIGN KEY (SCENARIONO, JOBNO) REFERENCES WEAVEJOB
)

CREATE TABLE REEDJOB (
  SCENARIONO INTEGER NOT NULL,
  LOOMNO INTEGER NOT NULL,
  JOBNO INTEGER NOT NULL,
  PLACENO INTEGER NOT NULL,
  TOTALENDS INTEGER NOT NULL,
  DENTSPERCM DOUBLE PRECISION NOT NULL,
  STARTDATE DATE,
  ENDDATE DATE,
  CONSTRAINT PREEDJOB PRIMARY KEY (SCENARIONO, JOBNO),
  CONSTRAINT FREEDJOBSCENARIONO FOREIGN KEY (SCENARIONO)
    REFERENCES SCENARIO
)

CREATE TABLE DOWNTIMEJOB (
  SCENARIONO INTEGER NOT NULL,
  LOOMNO INTEGER NOT NULL,
  JOBNO INTEGER NOT NULL,
  PLACENO INTEGER NOT NULL,
  DESCR CHAR(20) NOT NULL,
  STARTDATE DATE,
  ENDDATE DATE,
  CONSTRAINT PDOWNTIMEJOB PRIMARY KEY (SCENARIONO, JOBNO),
  CONSTRAINT FDOWNTIMEJOBSCENARIONO FOREIGN KEY (SCENARIONO)
    REFERENCES SCENARIO
)
